@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "8488df62afddb95d5be0ecf3be2ae3c430ca5fa7",
-  "branchName": "release",
-  "buildTime": "Tue, 14 Mar 2023 08:46:40 GMT",
-  "buildVersion": "5.1.219",
+  "commitId": "22b936a1d390f2be51c40130ef9b2787f7faed1a",
+  "branchName": "release-client-5.14.x",
+  "buildTime": "Sun, 28 May 2023 13:22:50 GMT",
+  "buildVersion": "261",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
-    "@zoom/client-scheduler/static/css/index.0cf63661.css"
+    "@zoom/client-scheduler/static/css/index.39b774a5.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.ca3385b0.js",
-    "@zoom/client-scheduler/static/js/index.742daf72.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.c685a8ed.js",
+    "@zoom/client-scheduler/static/js/index.23c56d52.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
